#include "BlockData/cblkGene.h"
c  #include "jamdat.f"
#include "jamdummy.h"
#include "phitsdummy.h"
c #include "Zphitsblk.h"
c       main program of cosmos
      program Cosmos
#include "ZcosmosExt.h"
#include "jamextrn.inc"
c///////////
c         call mydummy
c         call myPhitsDummy
c/////////////
         call cmanager   ! call Manager for Cosmos Simulation
      end


